<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// Fichier source, a modifier dans https://git.spip.net/spip/compresseur.git

return [

	// E
	'explication_url_statique_ressources' => 'Une URL qui permet de servir les fichiers statiques (images, JS…) sans cookie. Généralement un sous-domaine alternatif qui pointe aussi sur le site.',

	// I
	'info_compresseur_titre' => 'Optimisations et compression',
	'info_question_activer_compactage_css' => 'CSS',
	'info_question_activer_compactage_js' => 'Scripts',
	'item_compresseur_css' => 'Activer la compression des feuilles de style (CSS)',
	'item_compresseur_js' => 'Activer la compression des scripts (javascript)',

	// L
	'label_url_statique_ressources' => 'URL ressources',

	// T
	'texte_compacter_avertissement' => 'Attention à ne pas activer ces options durant le développement de votre site : les éléments compactés perdent toute lisibilité.',
	'texte_compacter_script_css' => 'SPIP peut compacter les scripts javascript et les feuilles de style CSS, pour les enregistrer dans des fichiers statiques ; cela accélère l’affichage du site.',
	'titre_compacter_script_css' => 'Compactage des scripts et CSS',
];
